diff src/structs.h @ 14764:f562b9fbd0d3 v8.1.0394

patch 8.1.0394: diffs are not always updated correctly commit https://github.com/vim/vim/commit/e3521d9cbb786806eaff106707851d37d2c0ecef Author: Bram Moolenaar <Bram@vim.org> Date: Sun Sep 16 14:10:31 2018 +0200 patch 8.1.0394: diffs are not always updated correctly Problem: Diffs are not always updated correctly. Solution: When using internal diff update for any changes properly.
author Christian Brabandt <cb@256bit.org>
date Sun, 16 Sep 2018 14:15:05 +0200
parents 1ae9c8a1b3bf
children a8ed1cb85859
line wrap: on
line diff
--- a/src/structs.h
+++ b/src/structs.h
@@ -2509,7 +2509,8 @@ struct tabpage_S
 #ifdef FEAT_DIFF
     diff_T	    *tp_first_diff;
     buf_T	    *(tp_diffbuf[DB_COUNT]);
-    int		    tp_diff_invalid;	/* list of diffs is outdated */
+    int		    tp_diff_invalid;	// list of diffs is outdated
+    int		    tp_diff_update;	// update diffs before redrawing
 #endif
     frame_T	    *(tp_snapshot[SNAP_COUNT]);  /* window layout snapshots */
 #ifdef FEAT_EVAL